@@ -278,7 +278,7 @@ class BaseChecker(metaclass=_CheckerMeta):
                 DeprecationWarning,
             )
             team_name = team_name or team
-        self.team: Optional[str] = team
+        self.team: Optional[str] = team_name
         self.team_id: int = team_id or -1  # TODO: make required
         if round:
             warnings.warn(
@@ -400,7 +400,38 @@ class BaseChecker(metaclass=_CheckerMeta):
 
     # ---- Basic checker functionality ---- #
 
-    def run(self, method: Optional[Union[str, Callable]] = None) -> CheckerResult:
+    def _run_method(self, method: Optional[str] = None) -> Optional[Result]:
+        """
+        Execute a checker method, pass all exceptions along to the calling function.
+
+        :param method: When calling run, you may call a different method than the one passed on Checker creation
+                        using this optional param.
+        :return: the Result code as int, as per the Result enum
+        """
+        if method not in CHECKER_METHODS:
+            raise ValueError(
+                "Method {} not supported! Supported: {}".format(method, CHECKER_METHODS)
+            )
+
+        # handle the cases where the original putflag/putnoise wasn't successful
+        if method == "getflag":
+            key = f"__Checker-internals-RESULT:putflag,{self.flag_round},{self.flag_idx}__"
+            if key not in self.team_db or self.team_db[key] != "OK":
+                self.info(
+                    f"original putflag did not return successfully -- ignoring getflag for flag_round:{self.flag_round}, index: {self.flag_idx}"
+                )
+                return Result.OK
+        elif method == "getnoise":
+            key = f"__Checker-internals-RESULT:putnoise,{self.flag_round},{self.flag_idx}__"
+            if key not in self.team_db or self.team_db[key] != "OK":
+                self.info(
+                    f"original putnoise did not return successfully -- ignoring getnoise for flag_round:{self.flag_round}, index: {self.flag_idx}"
+                )
+                return Result.OK
+
+        return getattr(self, snake_caseify(method))()
+
+    def run(self, method: Optional[str] = None) -> CheckerResult:
         """
         Execute the checker and catch errors along the way.
 
@@ -408,78 +439,34 @@ class BaseChecker(metaclass=_CheckerMeta):
                         using this optional param.
         :return: A CheckerResult as a representation of the CheckerResult response as definded in the Spec.
         """
+        if method is None:
+            method = self.method
+
         try:
-            if callable(method):
-                ret = method()
-            else:
-                if method is None:
-                    method = self.method
-                if method not in CHECKER_METHODS:
-                    raise ValueError(
-                        "Method {} not supported! Supported: {}".format(
-                            method, CHECKER_METHODS
-                        )
+            ret = self._run_method(method)
+            if ret is not None:
+                if not Result.is_valid(ret):
+                    self.error(
+                        "Illegal return value from {}: {}".format(self.method, ret)
                     )
+                    return CheckerResult(
+                        Result.INTERNAL_ERROR
+                    )  # , "Illegal return value from {}: {}".format(self.method, ret)
 
-                ignore_run = False
-                if method == "getflag":
-                    try:
-                        ignore_run = not (
-                            "OK"
-                            == self.team_db[
-                                f"__Checker-internals-RESULT:putflag,{self.flag_round},{self.flag_idx}__"
-                            ]
-                        )
-
-                    except KeyError:
-                        self.info(
-                            f"original putflag did not return successfully -- ignoring getflag for flag_round:{self.flag_round}, index: {self.flag_idx}"
-                        )
-                        ignore_run = True
-
-                if method == "getnoise":
-                    try:
-
-                        ignore_run = not (
-                            "OK"
-                            == self.team_db[
-                                f"__Checker-internals-RESULT:putnoise,{self.flag_round},{self.flag_idx}__"
-                            ]
-                        )
-
-                    except KeyError:
-                        self.info(
-                            f"original putnoise did not return successfully -- ignoring getnoise for flag_round:{self.flag_round}, index: {self.flag_idx}"
-                        )
-                        ignore_run = True
-
-                if ignore_run:
-                    self.debug("run ignored -- preemptively returned OK")
-                    return CheckerResult(Result.OK)
-
-                # call the function with the name method ""
-                ret = getattr(self, snake_caseify(method))()
-            if Result.is_valid(ret):
-                ret = Result(
-                    ret
-                )  # Better wrap this, in case somebody returns raw ints (?)
+                # Better wrap this, in case somebody returns raw ints (?)
+                ret = Result(ret)
                 self.info("Checker [{}] resulted in {}".format(self.method, ret.name))
                 self.team_db[
                     f"__Checker-internals-RESULT:{str(method)},{self.flag_round},{self.flag_idx}__"
                 ] = ret.name
                 return CheckerResult(ret)
-            if ret is not None:
-                self.error("Illegal return value from {}: {}".format(self.method, ret))
-                return CheckerResult(
-                    Result.INTERNAL_ERROR
-                )  # , "Illegal return value from {}: {}".format(self.method, ret)
 
             # Returned Normally
             self.info("Checker [{}] executed successfully!".format(self.method))
             self.team_db[
                 f"__Checker-internals-RESULT:{str(method)},{self.flag_round},{self.flag_idx}__"
             ] = "OK"
-            return CheckerResult(Result.OK, None)
+            return CheckerResult(Result.OK)
 
         except EnoException as eno:
             stacktrace = "".join(
@@ -495,6 +482,11 @@ class BaseChecker(metaclass=_CheckerMeta):
         except self.requests.HTTPError as ex:
             self.info("Service returned HTTP Errorcode [{}].".format(ex), exc_info=ex)
             return CheckerResult(Result.MUMBLE, "Service returned HTTP Error",)
+        except EOFError as ex:
+            self.info("Service returned EOF error [{}].".format(ex), exc_info=ex)
+            return CheckerResult(
+                Result.MUMBLE, "Service returned EOF while reading response."
+            )
         except (
             self.requests.ConnectionError,  # requests
             self.requests.exceptions.ConnectTimeout,  # requests
